from setuptools import setup, find_packages
setup(
      name="DiHttpMessageProcessor",
      version="0.2.2",
      packages=find_packages(where="."),
      install_requires=[
            'HttpMessageProcessor==0.12.1',
            'EdpDependencyInjection==0.2.1',
      ],
      url="http://www.e-deploy.com.br",
      author="Eduardo Almeida",
      author_email="eduardo.almeida@e-deploy.com.br"
)
